@@ -144,6 +144,8 @@ class IocContainer(dispatcher.EventDispatcherAware):
         if 'call_type' not in definition:
             # definition hasn't be retrieved yet, determine the type of
             # dependency
+            if 'item' not in definition:
+                definition['item'] = name
             obj = self._get_dependency(definition)
             call_type = self._get_type(obj)
             definition['call_type'] = call_type
